@@ -914,7 +914,7 @@ FwdState::connectStart()
     if (!fs->_peer && request->flags.spoof_client_ip) {
         // try to set the outgoing address using TPROXY v2
         // if it fails we abort any further TPROXY actions on this connection
-        if (IpInterceptor.SetTproxy2OutgoingAddr(int fd, const IpAddress &src) == -1) {
+        if (IpInterceptor.SetTproxy2OutgoingAddr(fd, src) == -1) {
             request->flags.spoof_client_ip = 0;
         }
     }
@@ -1360,7 +1360,12 @@ getOutgoingAddr(HttpRequest * request, struct peer *dst_peer)
     ch.dst_peer = dst_peer;
 
     if (request) {
-        ch.src_addr = request->client_addr;
+#if FOLLOW_X_FORWARDED_FOR
+        if (Config.onoff.acl_uses_indirect_client)
+            ch.src_addr = request->indirect_client_addr;
+        else
+#endif
+            ch.src_addr = request->client_addr;
         ch.my_addr = request->my_addr;
     }
 
