@@ -1352,6 +1352,28 @@ ipcacheMarkBadAddr(const char *name, IpAddress &addr)
     ipcacheCycleAddr(name, ia);
 }
 
+/// \ingroup IPCacheAPI
+void
+ipcacheMarkAllGood(const char *name)
+{
+    ipcache_entry *i;
+    ipcache_addrs *ia;
+    int k;
+
+    if ((i = ipcache_get(name)) == NULL)
+        return;
+
+    ia = &i->addrs;
+
+    /* All bad, reset to All good */
+    debugs(14, 3, "ipcacheMarkAllGood: Changing ALL " << name << " addrs to OK (" << ia->badcount << "/" << ia->count << " bad)");
+
+    for (k = 0; k < ia->count; k++)
+        ia->bad_mask[k] = 0;
+
+    ia->badcount = 0;
+}
+
 /// \ingroup IPCacheAPI
 void
 ipcacheMarkGoodAddr(const char *name, IpAddress &addr)
@@ -1489,8 +1511,8 @@ variable_list *
 snmp_netIpFn(variable_list * Var, snint * ErrP)
 {
     variable_list *Answer = NULL;
-    debugs(49, 5, "snmp_netIpFn: Processing request:");
-    snmpDebugOid(5, Var->name, Var->name_length);
+    MemBuf tmp;
+    debugs(49, 5, "snmp_netIpFn: Processing request:" << snmpDebugOid(Var->name, Var->name_length, tmp));
     *ErrP = SNMP_ERR_NOERROR;
 
     switch (Var->name[LEN_SQ_NET + 1]) {
