@@ -1,7 +1,7 @@
 /*
  * $Id$
  *
- * DEBUG: section 1     Startup and Main Loop
+ * DEBUG: section 01    Startup and Main Loop
  * AUTHOR: Harvest Derived
  *
  * SQUID Web Proxy Cache          http://www.squid-cache.org/
@@ -588,7 +588,7 @@ shut_down(int sig)
 #ifdef KILL_PARENT_OPT
 
     if (getppid() > 1) {
-        debugs(1, 1, "Killing RunCache, pid " << getppid());
+        debugs(1, 1, "Killing master process, pid " << getppid());
 
         if (kill(getppid(), sig) < 0)
             debugs(1, 1, "kill " << getppid() << ": " << xstrerror());
@@ -720,7 +720,11 @@ mainReconfigureFinish(void *)
     if (Config2.onoff.enable_purge)
         Config2.onoff.enable_purge = 2;
 
-    parseConfigFile(ConfigFile);
+    // parse the config returns a count of errors encountered.
+    if ( parseConfigFile(ConfigFile) != 0) {
+        // for now any errors are a fatal condition...
+        self_destruct();
+    }
 
     setUmask(Config.umask);
     Mem::Report();
@@ -732,6 +736,24 @@ mainReconfigureFinish(void *)
     parseEtcHosts();
     errorInitialize();		/* reload error pages */
     accessLogInit();
+
+#if USE_LOADABLE_MODULES
+    LoadableModulesConfigure(Config.loadable_module_names);
+#endif
+
+#if USE_ADAPTATION
+    bool enableAdaptation = false;
+#if ICAP_CLIENT
+    Adaptation::Icap::TheConfig.finalize();
+    enableAdaptation = Adaptation::Icap::TheConfig.onoff || enableAdaptation;
+#endif
+#if USE_ECAP
+    Adaptation::Ecap::TheConfig.finalize(); // must be after we load modules
+    enableAdaptation = Adaptation::Ecap::TheConfig.onoff || enableAdaptation;
+#endif
+    Adaptation::Config::Finalize(enableAdaptation);
+#endif
+
 #if ICAP_CLIENT
     icapLogOpen();
 #endif
@@ -1119,13 +1141,16 @@ static int SquidMainSafe(int argc, char **argv);
 /* When USE_WIN32_SERVICE is defined, the main function is placed in win32.cc */
 extern "C" void WINAPI
 SquidWinSvcMain(int argc, char **argv)
-#else
-int
-main(int argc, char **argv)
-#endif
 {
     SquidMainSafe(argc, argv);
 }
+#else
+int
+main(int argc, char **argv)
+{
+    return SquidMainSafe(argc, argv);
+}
+#endif
 
 static int
 SquidMainSafe(int argc, char **argv)
@@ -1260,8 +1285,7 @@ SquidMain(int argc, char **argv)
 
         Mem::Report();
 
-        if (opt_parse_cfg_only)
-
+        if (opt_parse_cfg_only || parse_err > 0)
             return parse_err;
     }
     setUmask(Config.umask);
