@@ -1,5 +1,5 @@
 /*
- * DEBUG: section 0     CGI Cache Manager
+ * DEBUG: section --    CGI Cache Manager
  * AUTHOR: Duane Wessels
  *
  * SQUID Web Proxy Cache          http://www.squid-cache.org/
@@ -31,6 +31,7 @@
  */
 
 #include "config.h"
+#include "rfc1738.h"
 
 #if HAVE_UNISTD_H
 #include <unistd.h>
@@ -568,7 +569,7 @@ munge_other_line(const char *buf, cachemgr_request * req)
 
     xfree(buf_copy);
     /* record ends */
-    l += snprintf(html + l, sizeof(html) - l, "</tr>\n");
+    snprintf(html + l, sizeof(html) - l, "</tr>\n");
     next_is_header = is_header && strstr(buf, "\t\t");
     table_line_num++;
     return html;
@@ -829,7 +830,7 @@ process_request(cachemgr_request * req)
 
     if ( !S.IsAnyAddr() ) {
         (void) 0;
-    } else if ( S = req->hostname)
+    } else if ((S = req->hostname))
         (void) 0;
     else {
         snprintf(buf, 1024, "Unknown host: %s\n", req->hostname);
@@ -1141,8 +1142,7 @@ make_auth_header(const cachemgr_request * req)
 
     assert(stringLength < sizeof(buf));
 
-    stringLength += snprintf(&buf[stringLength], sizeof(buf) - stringLength,
-                             "Proxy-Authorization: Basic %s\r\n", str64);
+    snprintf(&buf[stringLength], sizeof(buf) - stringLength, "Proxy-Authorization: Basic %s\r\n", str64);
 
     return buf;
 }
